# FaxsuiteResTfulApi.JobsApi

All URIs are relative to *https://service.fax-api.de/4.0/rest*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getJobs**](JobsApi.md#getJobs) | **GET** /jobs | /jobs
[**postJob**](JobsApi.md#postJob) | **POST** /jobs | /jobs

<a name="getJobs"></a>
# **getJobs**
> Jobs getJobs(opts)

/jobs

Description: Resource to obtain a list of fax jobs

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobsApi();
let opts = { 
  'objectLimit': 100, // Number | Query parameter to change de default limitation of objects in the result data array
  'objectOffset': 0, // Number | Query parameter to change de default offset of objects in the result data array
  'filterSameAccount': false, // Boolean | Query parameter to fetch jobs after the api account linked to the used token/key for authorization
  'filterTitle': "filterTitle_example", // String | Query parameter to fetch jobs after his title
  'filterStatus': "filterStatus_example", // String | Query parameter to fetch jobs after his status
  'filterDateFrom': new Date("2013-10-20T19:20:30+01:00"), // Date | Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
  'filterDateTo': new Date("2013-10-20T19:20:30+01:00"), // Date | Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
  'filterDateUntilFrom': new Date("2013-10-20T19:20:30+01:00"), // Date | Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
  'filterDateUntilTo': new Date("2013-10-20T19:20:30+01:00"), // Date | Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
  'filterCostCenter': "filterCostCenter_example", // String | Query parameter to fetch jobs after his cost center
  'sortField': "sortField_example", // String | Available sort options for the result data array.
  'sortOrder': "asc" // String | Describes the order for used sort fields
};
apiInstance.getJobs(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **objectLimit** | **Number**| Query parameter to change de default limitation of objects in the result data array | [optional] [default to 100]
 **objectOffset** | **Number**| Query parameter to change de default offset of objects in the result data array | [optional] [default to 0]
 **filterSameAccount** | **Boolean**| Query parameter to fetch jobs after the api account linked to the used token/key for authorization | [optional] [default to false]
 **filterTitle** | **String**| Query parameter to fetch jobs after his title | [optional] 
 **filterStatus** | **String**| Query parameter to fetch jobs after his status | [optional] 
 **filterDateFrom** | **Date**| Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional] 
 **filterDateTo** | **Date**| Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional] 
 **filterDateUntilFrom** | **Date**| Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional] 
 **filterDateUntilTo** | **Date**| Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional] 
 **filterCostCenter** | **String**| Query parameter to fetch jobs after his cost center | [optional] 
 **sortField** | **String**| Available sort options for the result data array. | [optional] 
 **sortOrder** | **String**| Describes the order for used sort fields | [optional] [default to asc]

### Return type

[**Jobs**](Jobs.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postJob"></a>
# **postJob**
> InlineResponse201 postJob(body)

/jobs

Description: Resource to create a new fax job

### Example
```javascript
import {FaxsuiteResTfulApi} from 'faxsuite_res_tful_api';
let defaultClient = FaxsuiteResTfulApi.ApiClient.instance;

// Configure API key authorization: ApiAuthKey
let ApiAuthKey = defaultClient.authentications['ApiAuthKey'];
ApiAuthKey.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiAuthKey.apiKeyPrefix = 'Token';

let apiInstance = new FaxsuiteResTfulApi.JobsApi();
let body = new FaxsuiteResTfulApi.JobPost(); // JobPost | Describes the required request body to create a new fax job

apiInstance.postJob(body, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**JobPost**](JobPost.md)| Describes the required request body to create a new fax job | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

